@@ -1,7 +1,7 @@
 #
 # backend.py: interface for backends
 #
-# Copyright 2008-2009 Canonical Ltd.
+# Copyright 2008-2010 Canonical Ltd.
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License version 3,
@@ -16,6 +16,7 @@
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
+import errno
 import os
 import re
 import stat
@@ -162,7 +163,7 @@ class UFWBackend:
 
                 path = os.path.dirname(path)
                 if not path:
-                    raise
+                    raise OSError(errno.ENOENT, "Could not find '%s'" % (path))
 
         for f in self.files:
             if f != 'apps' and not os.path.isfile(self.files[f]):
@@ -378,8 +379,8 @@ class UFWBackend:
                 # We assume that the rules are in app rule order. Specifically,
                 # if app rule has multiple rules, they are one after the other.
                 # If the rule ordering changes, the below will have to change.
-                tuple = r.get_app_tuple()
-                if tuple == last_tuple:
+                tupl = r.get_app_tuple()
+                if tupl == last_tuple:
                     # Skip the rule if seen this tuple already (ie, it is part
                     # of a known tuple).
                     continue
@@ -404,7 +405,7 @@ class UFWBackend:
                         else:
                             updated_rules.append(new_r)
 
-                    last_tuple = tuple
+                    last_tuple = tupl
                     updated_profile = True
             else:
                 if r.v6:
@@ -480,14 +481,14 @@ class UFWBackend:
         for i, r in enumerate(rules):
             if i >= position:
                 break
-            tuple = ""
+            tupl = ""
             if r.dapp != "" or r.sapp != "":
-                tuple = r.get_app_tuple()
+                tupl = r.get_app_tuple()
 
-                if app_rules.has_key(tuple):
+                if app_rules.has_key(tupl):
                     tuple_offset += 1
                 else:
-                    app_rules[tuple] = True
+                    app_rules[tupl] = True
 
         rules = []
         if v6:
@@ -540,7 +541,7 @@ class UFWBackend:
         try:
             self.set_default(self.files['conf'], "LOGLEVEL", new_level)
             self.update_logging(new_level)
-        except:
+        except Exception:
             raise
 
         if new_level == "off":
@@ -548,6 +549,10 @@ class UFWBackend:
         else:
             return _("Logging enabled")
 
+    def get_rules(self):
+        '''Return list of all rules'''
+        return self.rules + self.rules6
+
     def get_rules_count(self, v6):
         '''Return number of ufw rules (not iptables rules)'''
         rules = []
@@ -559,19 +564,54 @@ class UFWBackend:
         count = 0
         app_rules = {}
         for r in rules:
-            tuple = ""
+            tupl = ""
             if r.dapp != "" or r.sapp != "":
-                tuple = r.get_app_tuple()
+                tupl = r.get_app_tuple()
 
-                if app_rules.has_key(tuple):
-                    debug("Skipping found tuple '%s'" % (tuple))
+                if app_rules.has_key(tupl):
+                    debug("Skipping found tuple '%s'" % (tupl))
                     continue
                 else:
-                    app_rules[tuple] = True
+                    app_rules[tupl] = True
             count += 1
 
         return count
 
+    def get_rule_by_number(self, n):
+        '''Return rule specified by number seen via "status numbered"'''
+        rules = self.get_rules()
+
+        count = 1
+        app_rules = {}
+        for r in rules:
+            tupl = ""
+            if r.dapp != "" or r.sapp != "":
+                tupl = r.get_app_tuple()
+
+                if app_rules.has_key(tupl):
+                    debug("Skipping found tuple '%s'" % (tupl))
+                    continue
+                else:
+                    app_rules[tupl] = True
+            if count == int(n):
+                return r
+            count += 1
+        
+        return None
+
+    def get_matching(self, rule):
+        '''See if there is a matching rule in the existing ruleset. Note this
+           does not group rules by tuples.'''
+        matched = []
+        count = 0
+        for r in self.get_rules():
+            count += 1
+            ret = rule.fuzzy_dst_match(r)
+            if ret < 1:
+                matched.append(count)
+
+        return matched
+
     # API overrides
     def get_default_policy(self):
         raise UFWError("UFWBackend.get_default_policy: need to override")
@@ -579,7 +619,7 @@ class UFWBackend:
     def set_default_policy(self, policy, direction):
         raise UFWError("UFWBackend.set_default_policy: need to override")
 
-    def get_running_raw(self):
+    def get_running_raw(self, set):
         raise UFWError("UFWBackend.get_running_raw: need to override")
 
     def get_status(self, verbose, show_count):
@@ -604,4 +644,7 @@ class UFWBackend:
     def update_logging(self, level):
         raise UFWError("UFWBackend.update_logging: need to override")
 
+    def reset(self):
+        raise UFWError("UFWBackend.reset: need to override")
+
 
