@@ -282,7 +282,7 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
                 if rc != 0:
                     raise UFWError(err_msg + " ip6tables")
 
-        str = ""
+        s = ""
         str_out = ""
         rules = self.rules + self.rules6
         count = 1
@@ -290,17 +290,17 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
         for r in rules:
             tmp_str = ""
             location = {}
-            tuple = ""
+            tupl = ""
             show_proto = True
             if not verbose and (r.dapp != "" or r.sapp != ""):
                 show_proto = False
-                tuple = r.get_app_tuple()
+                tupl = r.get_app_tuple()
 
-                if app_rules.has_key(tuple):
-                    debug("Skipping found tuple '%s'" % (tuple))
+                if app_rules.has_key(tupl):
+                    debug("Skipping found tuple '%s'" % (tupl))
                     continue
                 else:
-                    app_rules[tuple] = True
+                    app_rules[tupl] = True
 
             for loc in [ 'dst', 'src' ]:
                 location[loc] = ""
@@ -381,7 +381,7 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
                 if len(attribs) > 0:
                     attrib_str = " (%s)" % (', '.join(attribs))
 
-            # now contruct the rule output string
+            # now construct the rule output string
             if show_count:
                 tmp_str += "[%2d] " % (count)
 
@@ -396,15 +396,15 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
             # Show the list in the order given if a numbered list, otherwise
             # split incoming and outgoing rules
             if show_count:
-                str += tmp_str
+                s += tmp_str
             else:
                 if r.direction == "out":
                     str_out += tmp_str
                 else:
-                    str += tmp_str
+                    s += tmp_str
             count += 1
 
-        if str != "" or str_out != "":
+        if s != "" or str_out != "":
             full_str = "\n\n"
             if show_count:
                 full_str += "     "
@@ -422,14 +422,14 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
                              "-" * len(str_action.decode("utf-8", 'ignore')), \
                              "-" * len(str_from.decode("utf-8", 'ignore')))
             full_str += rules_header.encode('utf-8', 'ignore')
-            if str != "":
-                full_str += str
-            if str != "" and str_out != "":
+            if s != "":
+                full_str += s
+            if s != "" and str_out != "":
                 full_str += _("\n")
             if str_out != "":
                 full_str += str_out
 
-            str = full_str
+            s = full_str
 
         if verbose:
             (level, logging_str) = self.get_loglevel()
@@ -439,9 +439,9 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
             app_policy_str = self.get_default_application_policy()
             return _("Status: active\n%(log)s\n%(pol)s\n%(app)s%(status)s") % \
                      ({'log': logging_str, 'pol': policy_str, \
-                       'app': app_policy_str, 'status': str})
+                       'app': app_policy_str, 'status': s})
         else:
-            return _("Status: active%s") % (str)
+            return _("Status: active%s") % (s)
 
     def stop_firewall(self):
         '''Stops the firewall'''
@@ -632,10 +632,10 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
             pat_tuple = re.compile(r'^### tuple ###\s*')
             for line in orig:
                 if pat_tuple.match(line):
-                    tuple = pat_tuple.sub('', line)
-                    tmp = re.split(r'\s+', tuple.strip())
+                    tupl = pat_tuple.sub('', line)
+                    tmp = re.split(r'\s+', tupl.strip())
                     if len(tmp) < 6 or len(tmp) > 9:
-                        warn_msg = _("Skipping malformed tuple (bad length): %s") % (tuple)
+                        warn_msg = _("Skipping malformed tuple (bad length): %s") % (tupl)
                         warn(warn_msg)
                         continue
                     else:
@@ -666,7 +666,7 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
 
                         except UFWError:
                             warn_msg = _("Skipping malformed tuple: %s") % \
-                                        (tuple)
+                                        (tupl)
                             warn(warn_msg)
                             continue
                         if f == self.files['rules6']:
@@ -1033,13 +1033,13 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
         norm = template.dup_rule()
         norm.set_v6(v6)
         norm.normalize()
-        tuple = norm.get_app_tuple()
+        tupl = norm.get_app_tuple()
 
         for r in rules:
             tmp = r.dup_rule()
             tmp.normalize()
             tmp_tuple = tmp.get_app_tuple()
-            if tmp_tuple == tuple:
+            if tmp_tuple == tupl:
                 app_rules.append(tmp)
 
         return app_rules
@@ -1183,6 +1183,13 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
                         rules_t.append([c, ['-I', c, '-m', 'state', \
                                             '--state', 'INVALID', \
                                             '-j', 'RETURN'] + largs, ''])
+                    else:
+                        rules_t.append([c, ['-A', c, '-m', 'state', \
+                                            '--state', 'INVALID', \
+                                            '-j', 'LOG', \
+                                            '--log-prefix', \
+                                            "[UFW AUDIT INVALID] "] + \
+                                        largs, ''])
                 rules_t.append([c, ['-A', c, '-j', 'LOG', \
                                     '--log-prefix', msg] + largs, ''])
 
@@ -1220,7 +1227,7 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
             if not os.path.isfile(fn):
                 err_msg = _("Could not find '%s'. Aborting") % (fn)
                 raise UFWError(err_msg)
-            
+
         ext = time.strftime("%Y%m%d_%H%M%S")
 
 	# This implementation will intentionally traceback if someone tries to
@@ -1236,7 +1243,8 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
         # Move the old to the new
         for i in all:
             fn = "%s.%s" % (i, ext)
-            res += _("Backing up '%s' to '%s'\n") % (os.path.basename(i), fn)
+            res += _("Backing up '%(old)s' to '%(new)s'\n") % (\
+                     {'old': os.path.basename(i), 'new': fn})
             os.rename(i, fn)
 
         # Copy files into place
@@ -1258,6 +1266,6 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
             if mode & stat.S_IWOTH:
                 res += _("WARN: '%s' is world writable") % (i)
             elif mode & stat.S_IROTH:
-                res += _("'WARN: %s' is world readable") % (i)
+                res += _("WARN: '%s' is world readable") % (i)
 
         return res
