@@ -218,11 +218,11 @@ iptables-save | grep '^-' > $TESTTMP/ipt.disable
 ip6tables-save | grep '^-' > $TESTTMP/ip6t.disable
 
 sed -i 's/^ENABLED=no/ENABLED=yes/' $TESTPATH/etc/ufw/ufw.conf
-do_extcmd "0" null $RELTESTPATH/lib/ufw/ufw-init start
+do_extcmd "0" null $TESTPATH/lib/ufw/ufw-init start
 iptables-save | grep '^-' > $TESTTMP/ipt.start
 ip6tables-save | grep '^-' > $TESTTMP/ip6t.start
 
-do_extcmd "0" null $RELTESTPATH/lib/ufw/ufw-init stop
+do_extcmd "0" null $TESTPATH/lib/ufw/ufw-init stop
 iptables-save | grep '^-' > $TESTTMP/ipt.stop
 ip6tables-save | grep '^-' > $TESTTMP/ip6t.stop
 
@@ -255,7 +255,7 @@ echo "Verify toplevel chains" >> $TESTTMP/result
 for l in off on low medium high full; do
     do_cmd "0" nostats logging $l
     do_cmd "0" nostats disable
-    $TESTSTATE/ufw-init flush-all >> $TESTTMP/result 2>&1
+    $TESTSTATE/ufw-init flush-all >/dev/null
     do_cmd "0" nostats enable
     for b in INPUT OUTPUT FORWARD; do
         for c in before-logging before after after-logging reject track ; do
@@ -280,7 +280,7 @@ echo "Verify secondary chains" >> $TESTTMP/result
 for l in off on low medium high full; do
     do_cmd "0" nostats logging $l
     do_cmd "0" nostats disable
-    $TESTSTATE/ufw-init flush-all >> $TESTTMP/result 2>&1
+    $TESTSTATE/ufw-init flush-all >/dev/null
     do_cmd "0" nostats enable
     for c in logging-deny not-local user-forward user-input user-output skip-to-policy-input ; do
         echo "$count: ! iptables -L ufw-$c -n | egrep -q '0 references'" >> $TESTTMP/result
@@ -326,6 +326,95 @@ done
 do_cmd "0" nostats enable
 do_cmd "0" nostats delete allow 22/tcp
 
+echo "Reset test" >> $TESTTMP/result
+do_cmd "0" nostats enable
+do_cmd "0" nostats allow 12345
+let rules_num="0"
+for i in `ls $TESTPATH/etc/ufw/*.rules && ls $TESTSTATE/*.rules` ; do
+    let rules_num=rules_num+1
+done
+do_cmd "0" null reset
+
+let rules_bak_num="0"
+for i in `ls $TESTPATH/etc/ufw/*.rules.2* && ls $TESTSTATE/*.rules.2*` ; do
+    let rules_bak_num=rules_bak_num+1
+done
+if [ "$rules_num" != "$rules_bak_num" ]; then
+    echo "'ufw-init reset' failed ('$rules_num' != '$rules_bak_num')" >> $TESTTMP/result
+    exit 1
+fi
+iptables -L ufw-user-input -n >/dev/null 2>&1 && {
+    echo "Failed: found 'ufw-user-input', still running." >> $TESTTMP/result
+    exit 1
+}
+grep -v -q 12345 $TESTSTATE/user.rules || {
+    echo "Failed: found '12345' in user.rules" >> $TESTTMP/result
+    exit 1
+}
+
+echo "Show" >> $TESTTMP/result
+for ipv6 in yes no
+do
+    echo "Setting IPV6 to $ipv6" >> $TESTTMP/result
+    sed -i "s/IPV6=.*/IPV6=$ipv6/" $TESTPATH/etc/default/ufw
+    do_cmd "0" nostats disable
+    do_cmd "0" nostats enable
+    cmds="raw builtins before-rules user-rules after-rules logging-rules listening"
+    for i in $cmds; do
+        do_cmd "0" null show $i
+    done
+done
+do_cmd "0" nostats disable
+
+echo "Delete by number" >> $TESTTMP/result
+for ipv6 in yes no
+do
+    echo "Setting IPV6 to $ipv6" >> $TESTTMP/result
+    sed -i "s/IPV6=.*/IPV6=$ipv6/" $TESTPATH/etc/default/ufw
+    do_cmd "0" nostats disable
+    do_cmd "0" nostats enable
+
+    for i in 1 2 3 4; do
+        do_cmd "0" nostats allow $i
+    done
+
+    grep -A2 "tuple" $TESTSTATE/user.rules >> $TESTTMP/result
+    if [ "$ipv6" = "yes" ]; then
+        grep -A2 "tuple" $TESTSTATE/user6.rules >> $TESTTMP/result
+    fi
+
+    for i in 4 3 2 1; do
+        grep -q "^### tuple ### allow any $i " $TESTSTATE/user.rules || {
+            echo "Failed: Could not find port '$i' user.rules" >> $TESTTMP/result
+            exit 1
+        }
+        if [ "$ipv6" = "yes" ]; then
+            grep -q "^### tuple ### allow any $i " $TESTSTATE/user6.rules || {
+                echo "Failed: Could not find port '$i' user6.rules" >> $TESTTMP/result
+                exit 1
+            }
+        fi
+
+        if [ "$ipv6" = "yes" ]; then
+            do_cmd "0" null --force delete $((i+i))
+            grep -v -q "^### tuple ### allow any $i " $TESTSTATE/user6.rules || {
+                echo "Failed: Found port '$i' user6.rules" >> $TESTTMP/result
+                exit 1
+            }
+            grep -A2 "tuple" $TESTSTATE/user6.rules >> $TESTTMP/result
+        fi
+        do_cmd "0" null --force delete $i
+        grep -v -q "^### tuple ### allow any $i " $TESTSTATE/user.rules || {
+            echo "Failed: Found port '$i' user.rules" >> $TESTTMP/result
+            exit 1
+        }
+        grep -A2 "tuple" $TESTSTATE/user.rules >> $TESTTMP/result
+    done
+done
+grep -A2 "tuple" $TESTSTATE/user.rules >> $TESTTMP/result
+grep -A2 "tuple" $TESTSTATE/user6.rules >> $TESTTMP/result
+do_cmd "0" nostats disable
+
 cleanup
 
 exit 0
